Documentation
¶
Index ¶
- Constants
- Variables
- func BlockedAddresses() map[string]bool
- func DefineCustomGetSigners(signingOptions *signing.Options)
- func GetMaccPerms() map[string][]string
- func MakeEncodingConfig(basicManager module.BasicManager) params.EncodingConfig
- func RegisterSwaggerAPI(rtr *mux.Router)
- type GaiaApp
- func (app *GaiaApp) AppCodec() codec.Codec
- func (app *GaiaApp) AutoCliOpts() autocli.AppOptions
- func (app *GaiaApp) BeginBlocker(ctx sdk.Context) (sdk.BeginBlock, error)
- func (app *GaiaApp) CheckControllerInited(expected bool)
- func (app *GaiaApp) Commit() (*abci.ResponseCommit, error)
- func (app *GaiaApp) DefaultGenesis() GenesisState
- func (app *GaiaApp) EndBlocker(ctx sdk.Context) (sdk.EndBlock, error)
- func (app *GaiaApp) ExportAppStateAndValidators(forZeroHeight bool, jailAllowedAddrs []string, modulesToExport []string) (servertypes.ExportedApp, error)
- func (app *GaiaApp) GetBaseApp() *baseapp.BaseApp
- func (app *GaiaApp) GetIBCKeeper() *ibckeeper.Keeper
- func (app *GaiaApp) GetKey(storeKey string) *storetypes.KVStoreKey
- func (app *GaiaApp) GetMemKey(storeKey string) *storetypes.MemoryStoreKey
- func (app *GaiaApp) GetScopedIBCKeeper() capabilitykeeper.ScopedKeeper
- func (app *GaiaApp) GetStakingKeeper() testtypes.StakingKeeper
- func (app *GaiaApp) GetSubspace(moduleName string) paramstypes.Subspace
- func (app *GaiaApp) GetTKey(storeKey string) *storetypes.TransientStoreKey
- func (app *GaiaApp) GetTxConfig() client.TxConfig
- func (app *GaiaApp) InitChainer(ctx sdk.Context, req *abci.RequestInitChain) (*abci.ResponseInitChain, error)
- func (app *GaiaApp) InterfaceRegistry() types.InterfaceRegistry
- func (app *GaiaApp) LegacyAmino() *codec.LegacyAmino
- func (app *GaiaApp) LoadHeight(height int64) error
- func (app *GaiaApp) ModuleAccountAddrs() map[string]bool
- func (app *GaiaApp) Name() string
- func (app *GaiaApp) PreBlocker(ctx sdk.Context, _ *abci.RequestFinalizeBlock) (*sdk.ResponsePreBlock, error)
- func (app *GaiaApp) RegisterAPIRoutes(apiSvr *api.Server, apiConfig config.APIConfig)
- func (app *GaiaApp) RegisterNodeService(clientCtx client.Context, cfg config.Config)
- func (app *GaiaApp) RegisterTendermintService(clientCtx client.Context)
- func (app *GaiaApp) RegisterTxService(clientCtx client.Context)
- func (app *GaiaApp) RegisterUpgradeHandlers()
- func (app *GaiaApp) SetSwingStoreExportDir(dir string)
- func (app *GaiaApp) SimulationManager() *module.SimulationManager
- type GenesisState
- type SimGenesisAccount
Constants ¶
const ( // FlagSwingStoreExportDir defines the config flag used to specify where a // genesis swing-store export is expected. For start from genesis, the default // value is config/swing-store in the home directory. For genesis export, the // value is always a "swing-store" directory sibling to the exported // genesis.json file. // TODO: document this flag in config, likely alongside the genesis path FlagSwingStoreExportDir = "swing-store-export-dir" // FlagSwingStoreExportMode defines the export mode for the swing store // Alongside the default mode `operational`, there are two other modes // // 1- `skip` mode will skip the swing store export altogether // // 2- `debug` mode will export all the available store FlagSwingStoreExportMode = "swing-store-export-mode" )
Variables ¶
var ( // DefaultNodeHome default home directories for the application daemon DefaultNodeHome string )
Functions ¶
func BlockedAddresses ¶
BlockedAddresses returns the app's module account addresses that are blocked from receiving funds.
func DefineCustomGetSigners ¶
func GetMaccPerms ¶
GetMaccPerms returns a copy of the module account permissions
func MakeEncodingConfig ¶
func MakeEncodingConfig(basicManager module.BasicManager) params.EncodingConfig
MakeEncodingConfig creates an EncodingConfig for testing
func RegisterSwaggerAPI ¶
RegisterSwaggerAPI registers swagger route with API Server
Types ¶
type GaiaApp ¶
type GaiaApp struct {
*baseapp.BaseApp
// manage communication from the VM to the ABCI app
AgdServer *vm.AgdServer
// keepers
AccountKeeper authkeeper.AccountKeeper
BankKeeper bankkeeper.Keeper
CapabilityKeeper *capabilitykeeper.Keeper
StakingKeeper *stakingkeeper.Keeper
SlashingKeeper slashingkeeper.Keeper
MintKeeper mintkeeper.Keeper
DistrKeeper distrkeeper.Keeper
GovKeeper *govkeeper.Keeper
UpgradeKeeper *upgradekeeper.Keeper
ParamsKeeper paramskeeper.Keeper
ConsensusParamsKeeper consensusparamskeeper.Keeper
// IBC Keeper must be a pointer in the app, so we can SetRouter on it correctly
IBCKeeper *ibckeeper.Keeper
ICAHostKeeper icahostkeeper.Keeper
PacketForwardKeeper *packetforwardkeeper.Keeper
EvidenceKeeper evidencekeeper.Keeper
TransferKeeper ibctransferkeeper.Keeper
FeeGrantKeeper feegrantkeeper.Keeper
AuthzKeeper authzkeeper.Keeper
SwingStoreExportsHandler swingset.SwingStoreExportsHandler
SwingSetSnapshotter swingset.ExtensionSnapshotter
SwingSetKeeper swingset.Keeper
VstorageKeeper vstorage.Keeper
VibcKeeper vibc.Keeper
VbankKeeper vbank.Keeper
VlocalchainKeeper vlocalchain.Keeper
VtransferKeeper vtransferkeeper.Keeper
// make scoped keepers public for test purposes
ScopedIBCKeeper capabilitykeeper.ScopedKeeper
ScopedTransferKeeper capabilitykeeper.ScopedKeeper
ScopedICAHostKeeper capabilitykeeper.ScopedKeeper
ScopedVibcKeeper capabilitykeeper.ScopedKeeper
// the module managers
ModuleManager *module.Manager
BasicModuleManager module.BasicManager
// contains filtered or unexported fields
}
GaiaApp extends an ABCI application, but with most of its parameters exported. They are exported for convenience in cr1eating helper functions, as object capabilities aren't needed for testing.
func NewAgoricApp ¶
func NewSimApp ¶
func NewSimApp( logger log.Logger, db dbm.DB, traceStore io.Writer, loadLatest bool, appOpts servertypes.AppOptions, baseAppOptions ...func(*baseapp.BaseApp), ) *GaiaApp
NewSimApp returns a reference to an initialized sim app.
func (*GaiaApp) AppCodec ¶
AppCodec returns Gaia's app codec.
NOTE: This is solely to be used for testing purposes as it may be desirable for modules to register their own custom testing types.
func (*GaiaApp) AutoCliOpts ¶
func (app *GaiaApp) AutoCliOpts() autocli.AppOptions
func (*GaiaApp) BeginBlocker ¶
BeginBlocker application updates every begin block
func (*GaiaApp) CheckControllerInited ¶
CheckControllerInited exits if the controller initialization state does not match `expected`.
func (*GaiaApp) Commit ¶
func (app *GaiaApp) Commit() (*abci.ResponseCommit, error)
Commit tells the controller that the block is commited
func (*GaiaApp) DefaultGenesis ¶
func (app *GaiaApp) DefaultGenesis() GenesisState
func (*GaiaApp) EndBlocker ¶
EndBlocker application updates every end block
func (*GaiaApp) ExportAppStateAndValidators ¶
func (app *GaiaApp) ExportAppStateAndValidators( forZeroHeight bool, jailAllowedAddrs []string, modulesToExport []string, ) (servertypes.ExportedApp, error)
ExportAppStateAndValidators exports the state of the application for a genesis file.
func (*GaiaApp) GetBaseApp ¶
GetBaseApp implements the TestingApp interface.
func (*GaiaApp) GetIBCKeeper ¶
GetIBCKeeper implements the TestingApp interface.
func (*GaiaApp) GetKey ¶
func (app *GaiaApp) GetKey(storeKey string) *storetypes.KVStoreKey
GetKey returns the KVStoreKey for the provided store key.
NOTE: This is solely to be used for testing purposes.
func (*GaiaApp) GetMemKey ¶
func (app *GaiaApp) GetMemKey(storeKey string) *storetypes.MemoryStoreKey
GetMemKey returns the MemStoreKey for the provided mem key.
NOTE: This is solely used for testing purposes.
func (*GaiaApp) GetScopedIBCKeeper ¶
func (app *GaiaApp) GetScopedIBCKeeper() capabilitykeeper.ScopedKeeper
GetScopedIBCKeeper implements the TestingApp interface.
func (*GaiaApp) GetStakingKeeper ¶
func (app *GaiaApp) GetStakingKeeper() testtypes.StakingKeeper
GetStakingKeeper implements the TestingApp interface.
func (*GaiaApp) GetSubspace ¶
func (app *GaiaApp) GetSubspace(moduleName string) paramstypes.Subspace
GetSubspace returns a param subspace for a given module name.
NOTE: This is solely to be used for testing purposes.
func (*GaiaApp) GetTKey ¶
func (app *GaiaApp) GetTKey(storeKey string) *storetypes.TransientStoreKey
GetTKey returns the TransientStoreKey for the provided store key.
NOTE: This is solely to be used for testing purposes.
func (*GaiaApp) GetTxConfig ¶
GetTxConfig implements the TestingApp interface.
func (*GaiaApp) InitChainer ¶
func (app *GaiaApp) InitChainer(ctx sdk.Context, req *abci.RequestInitChain) (*abci.ResponseInitChain, error)
InitChainer application update at chain initialization
func (*GaiaApp) InterfaceRegistry ¶
func (app *GaiaApp) InterfaceRegistry() types.InterfaceRegistry
InterfaceRegistry returns Gaia's InterfaceRegistry
func (*GaiaApp) LegacyAmino ¶
func (app *GaiaApp) LegacyAmino() *codec.LegacyAmino
LegacyAmino returns GaiaApp's amino codec.
NOTE: This is solely to be used for testing purposes as it may be desirable for modules to register their own custom testing types.
func (*GaiaApp) LoadHeight ¶
LoadHeight loads a particular height
func (*GaiaApp) ModuleAccountAddrs ¶
ModuleAccountAddrs returns all the app's module account addresses.
func (*GaiaApp) PreBlocker ¶
func (app *GaiaApp) PreBlocker(ctx sdk.Context, _ *abci.RequestFinalizeBlock) (*sdk.ResponsePreBlock, error)
PreBlocker application updates before each begin block.
func (*GaiaApp) RegisterAPIRoutes ¶
RegisterAPIRoutes registers all application module routes with the provided API server.
func (*GaiaApp) RegisterNodeService ¶
RegisterNodeService implements the Application.RegisterNodeService method.
func (*GaiaApp) RegisterTendermintService ¶
RegisterTendermintService implements the Application.RegisterTendermintService method.
func (*GaiaApp) RegisterTxService ¶
RegisterTxService implements the Application.RegisterTxService method.
func (*GaiaApp) RegisterUpgradeHandlers ¶
func (app *GaiaApp) RegisterUpgradeHandlers()
RegisterUpgradeHandlers registers the upgrade handlers for all upgradeNames.
func (*GaiaApp) SetSwingStoreExportDir ¶
For testing purposes
func (*GaiaApp) SimulationManager ¶
func (app *GaiaApp) SimulationManager() *module.SimulationManager
SimulationManager implements the SimulationApp interface
type GenesisState ¶
type GenesisState map[string]json.RawMessage
The genesis state of the blockchain is represented here as a map of raw json messages key'd by a identifier string. The identifier is used to determine which module genesis information belongs to so it may be appropriately routed during init chain. Within this application default genesis information is retrieved from the ModuleBasicManager which populates json from each BasicModule object provided to it during init.
func NewDefaultGenesisState ¶
func NewDefaultGenesisState(appCodec codec.Codec, basicManager module.BasicManager) GenesisState
NewDefaultGenesisState generates the default state for the application.
type SimGenesisAccount ¶
type SimGenesisAccount struct {
*authtypes.BaseAccount
// vesting account fields
OriginalVesting sdk.Coins `json:"original_vesting" yaml:"original_vesting"` // total vesting coins upon initialization
DelegatedFree sdk.Coins `json:"delegated_free" yaml:"delegated_free"` // delegated vested coins at time of delegation
DelegatedVesting sdk.Coins `json:"delegated_vesting" yaml:"delegated_vesting"` // delegated vesting coins at time of delegation
StartTime int64 `json:"start_time" yaml:"start_time"` // vesting start time (UNIX Epoch time)
EndTime int64 `json:"end_time" yaml:"end_time"` // vesting end time (UNIX Epoch time)
// module account fields
ModuleName string `json:"module_name" yaml:"module_name"` // name of the module account
ModulePermissions []string `json:"module_permissions" yaml:"module_permissions"` // permissions of module account
}
SimGenesisAccount defines a type that implements the GenesisAccount interface to be used for simulation accounts in the genesis state.
func (SimGenesisAccount) Validate ¶
func (sga SimGenesisAccount) Validate() error
Validate checks for errors on the vesting and module account parameters