Documentation
¶
Index ¶
- Constants
- Variables
- func DefaultGenesisState() *types.GenesisState
- func ExportGenesis(ctx sdk.Context, keeper Keeper) (*types.GenesisState, error)
- func InitGenesis(ctx sdk.Context, keeper Keeper, data *types.GenesisState) error
- func NewGenesisState() *types.GenesisState
- func NewHandler(k Keeper) baseapp.MsgServiceHandler
- func NewStorageHandler(keeper Keeper) vstorageHandler
- func ValidateGenesis(data *types.GenesisState) error
- type AppModule
- func (am AppModule) BeginBlock(ctx context.Context) error
- func (AppModule) ConsensusVersion() uint64
- func (am AppModule) EndBlock(ctx context.Context) error
- func (am AppModule) ExportGenesis(ctx sdk.Context, cdc codec.JSONCodec) json.RawMessage
- func (am AppModule) InitGenesis(ctx sdk.Context, cdc codec.JSONCodec, data json.RawMessage)
- func (am AppModule) IsAppModule()
- func (am AppModule) IsOnePerModuleType()
- func (AppModule) Name() string
- func (am AppModule) RegisterInvariants(ir sdk.InvariantRegistry)
- func (am AppModule) RegisterServices(cfg module.Configurator)
- type AppModuleBasic
- func (AppModuleBasic) DefaultGenesis(cdc codec.JSONCodec) json.RawMessage
- func (AppModuleBasic) GetQueryCmd() *cobra.Command
- func (AppModuleBasic) GetTxCmd() *cobra.Command
- func (AppModuleBasic) Name() string
- func (AppModuleBasic) RegisterGRPCGatewayRoutes(clientCtx client.Context, mux *runtime.ServeMux)
- func (b AppModuleBasic) RegisterInterfaces(registry cdctypes.InterfaceRegistry)
- func (AppModuleBasic) RegisterLegacyAminoCodec(cdc *codec.LegacyAmino)
- func (AppModuleBasic) ValidateGenesis(cdc codec.JSONCodec, config client.TxEncodingConfig, bz json.RawMessage) error
- type Data
- type Keeper
Constants ¶
const ( ModuleName = types.ModuleName StoreKey = types.StoreKey )
Variables ¶
var ( NewKeeper = keeper.NewKeeper NewStorage = types.NewData NewChildren = types.NewChildren )
Functions ¶
func DefaultGenesisState ¶
func DefaultGenesisState() *types.GenesisState
func ExportGenesis ¶
func InitGenesis ¶
func NewGenesisState ¶
func NewGenesisState() *types.GenesisState
func NewHandler ¶
func NewHandler(k Keeper) baseapp.MsgServiceHandler
NewHandler returns a handler for "vstorage" type messages.
func NewStorageHandler ¶
func NewStorageHandler(keeper Keeper) vstorageHandler
func ValidateGenesis ¶
func ValidateGenesis(data *types.GenesisState) error
Types ¶
type AppModule ¶
type AppModule struct {
AppModuleBasic
// contains filtered or unexported fields
}
func NewAppModule ¶
NewAppModule creates a new AppModule Object
func (AppModule) ConsensusVersion ¶
func (AppModule) ExportGenesis ¶
func (AppModule) InitGenesis ¶
func (AppModule) IsAppModule ¶
func (am AppModule) IsAppModule()
IsAppModule implements the appmodule.AppModule interface.
func (AppModule) IsOnePerModuleType ¶
func (am AppModule) IsOnePerModuleType()
IsOnePerModuleType is a marker function just indicates that this is a one-per-module type.
func (AppModule) RegisterInvariants ¶
func (am AppModule) RegisterInvariants(ir sdk.InvariantRegistry)
func (AppModule) RegisterServices ¶
func (am AppModule) RegisterServices(cfg module.Configurator)
type AppModuleBasic ¶
type AppModuleBasic struct {
}
app module Basics object
func (AppModuleBasic) DefaultGenesis ¶
func (AppModuleBasic) DefaultGenesis(cdc codec.JSONCodec) json.RawMessage
DefaultGenesis returns default genesis state as raw bytes for the deployment
func (AppModuleBasic) GetQueryCmd ¶
func (AppModuleBasic) GetQueryCmd() *cobra.Command
Get the root query command of this module
func (AppModuleBasic) GetTxCmd ¶
func (AppModuleBasic) GetTxCmd() *cobra.Command
Get the root tx command of this module
func (AppModuleBasic) Name ¶
func (AppModuleBasic) Name() string
func (AppModuleBasic) RegisterGRPCGatewayRoutes ¶
func (AppModuleBasic) RegisterGRPCGatewayRoutes(clientCtx client.Context, mux *runtime.ServeMux)
func (AppModuleBasic) RegisterInterfaces ¶
func (b AppModuleBasic) RegisterInterfaces(registry cdctypes.InterfaceRegistry)
RegisterInterfaces registers the module's interface types
func (AppModuleBasic) RegisterLegacyAminoCodec ¶
func (AppModuleBasic) RegisterLegacyAminoCodec(cdc *codec.LegacyAmino)
func (AppModuleBasic) ValidateGenesis ¶
func (AppModuleBasic) ValidateGenesis(cdc codec.JSONCodec, config client.TxEncodingConfig, bz json.RawMessage) error
Validation check of the Genesis
Click to show internal directories.
Click to hide internal directories.